"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.opensearch.v1.auth_pb2
import yandex.cloud.mdb.opensearch.v1.cluster_pb2
import yandex.cloud.mdb.opensearch.v1.cluster_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ClusterServiceStub:
    """A set of methods for managing OpenSearch clusters."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.GetClusterRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster,
    ]
    """Returns the specified OpenSearch cluster.

    To get the list of all available OpenSearch clusters, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersResponse,
    ]
    """Retrieves the list of OpenSearch clusters that belong to the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.CreateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OpenSearch cluster in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified OpenSearch cluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OpenSearch cluster."""

    Backup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.BackupClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a backup for the specified OpenSearch cluster."""

    Restore: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.RestoreClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new OpenSearch cluster using the specified backup."""

    RescheduleMaintenance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.RescheduleMaintenanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reschedules a planned maintenance operation."""

    ListBackups: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsResponse,
    ]
    """Returns a list of available backups for the specified OpenSearch cluster."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.MoveClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified OpenSearch cluster to the specified folder."""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StartClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified OpenSearch cluster."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StopClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified OpenSearch cluster."""

    ListLogs: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsResponse,
    ]
    """Retrieves logs for the specified OpenSearch cluster.
    For detailed description, see the [Logs](/yandex-mdb-guide/concepts/logs.html) section in the developer's guide.
    """

    StreamLogs: grpc.UnaryStreamMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamClusterLogsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamLogRecord,
    ]
    """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsResponse,
    ]
    """Retrieves the list of Operation resources for the specified cluster."""

    ListHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsResponse,
    ]
    """Retrieves a list of hosts for the specified cluster."""

    AddOpenSearchNodeGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.AddOpenSearchNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OpenSearch type host group."""

    DeleteOpenSearchNodeGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteOpenSearchNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes an OpenSearch type host group."""

    UpdateOpenSearchNodeGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateOpenSearchNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an OpenSearch type host group."""

    AddDashboardsNodeGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.AddDashboardsNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a Dashboards type host group."""

    DeleteDashboardsNodeGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteDashboardsNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a Dashboards type host group."""

    UpdateDashboardsNodeGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateDashboardsNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a Dashboards type host group."""

    GetAuthSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.GetAuthSettingsRequest,
        yandex.cloud.mdb.opensearch.v1.auth_pb2.AuthSettings,
    ]
    """Retrieves auth settings for specified cluster."""

    UpdateAuthSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateAuthSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates auth settings for specified cluster."""

class ClusterServiceAsyncStub:
    """A set of methods for managing OpenSearch clusters."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.GetClusterRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster,
    ]
    """Returns the specified OpenSearch cluster.

    To get the list of all available OpenSearch clusters, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersResponse,
    ]
    """Retrieves the list of OpenSearch clusters that belong to the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.CreateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OpenSearch cluster in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified OpenSearch cluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OpenSearch cluster."""

    Backup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.BackupClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a backup for the specified OpenSearch cluster."""

    Restore: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.RestoreClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new OpenSearch cluster using the specified backup."""

    RescheduleMaintenance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.RescheduleMaintenanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reschedules a planned maintenance operation."""

    ListBackups: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsResponse,
    ]
    """Returns a list of available backups for the specified OpenSearch cluster."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.MoveClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified OpenSearch cluster to the specified folder."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StartClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified OpenSearch cluster."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StopClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified OpenSearch cluster."""

    ListLogs: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsResponse,
    ]
    """Retrieves logs for the specified OpenSearch cluster.
    For detailed description, see the [Logs](/yandex-mdb-guide/concepts/logs.html) section in the developer's guide.
    """

    StreamLogs: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamClusterLogsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamLogRecord,
    ]
    """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsResponse,
    ]
    """Retrieves the list of Operation resources for the specified cluster."""

    ListHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsRequest,
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsResponse,
    ]
    """Retrieves a list of hosts for the specified cluster."""

    AddOpenSearchNodeGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.AddOpenSearchNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OpenSearch type host group."""

    DeleteOpenSearchNodeGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteOpenSearchNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes an OpenSearch type host group."""

    UpdateOpenSearchNodeGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateOpenSearchNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an OpenSearch type host group."""

    AddDashboardsNodeGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.AddDashboardsNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a Dashboards type host group."""

    DeleteDashboardsNodeGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteDashboardsNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a Dashboards type host group."""

    UpdateDashboardsNodeGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateDashboardsNodeGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a Dashboards type host group."""

    GetAuthSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.GetAuthSettingsRequest,
        yandex.cloud.mdb.opensearch.v1.auth_pb2.AuthSettings,
    ]
    """Retrieves auth settings for specified cluster."""

    UpdateAuthSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateAuthSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates auth settings for specified cluster."""

class ClusterServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing OpenSearch clusters."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.GetClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster]]:
        """Returns the specified OpenSearch cluster.

        To get the list of all available OpenSearch clusters, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersResponse, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClustersResponse]]:
        """Retrieves the list of OpenSearch clusters that belong to the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.CreateClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an OpenSearch cluster in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified OpenSearch cluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified OpenSearch cluster."""

    @abc.abstractmethod
    def Backup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.BackupClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a backup for the specified OpenSearch cluster."""

    @abc.abstractmethod
    def Restore(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.RestoreClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new OpenSearch cluster using the specified backup."""

    @abc.abstractmethod
    def RescheduleMaintenance(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.RescheduleMaintenanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reschedules a planned maintenance operation."""

    @abc.abstractmethod
    def ListBackups(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsResponse, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterBackupsResponse]]:
        """Returns a list of available backups for the specified OpenSearch cluster."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.MoveClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified OpenSearch cluster to the specified folder."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StartClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the specified OpenSearch cluster."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StopClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified OpenSearch cluster."""

    @abc.abstractmethod
    def ListLogs(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsResponse, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterLogsResponse]]:
        """Retrieves logs for the specified OpenSearch cluster.
        For detailed description, see the [Logs](/yandex-mdb-guide/concepts/logs.html) section in the developer's guide.
        """

    @abc.abstractmethod
    def StreamLogs(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamClusterLogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamLogRecord], collections.abc.AsyncIterator[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.StreamLogRecord]]:
        """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsResponse, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterOperationsResponse]]:
        """Retrieves the list of Operation resources for the specified cluster."""

    @abc.abstractmethod
    def ListHosts(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsResponse, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.ListClusterHostsResponse]]:
        """Retrieves a list of hosts for the specified cluster."""

    @abc.abstractmethod
    def AddOpenSearchNodeGroup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.AddOpenSearchNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an OpenSearch type host group."""

    @abc.abstractmethod
    def DeleteOpenSearchNodeGroup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteOpenSearchNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes an OpenSearch type host group."""

    @abc.abstractmethod
    def UpdateOpenSearchNodeGroup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateOpenSearchNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an OpenSearch type host group."""

    @abc.abstractmethod
    def AddDashboardsNodeGroup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.AddDashboardsNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a Dashboards type host group."""

    @abc.abstractmethod
    def DeleteDashboardsNodeGroup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.DeleteDashboardsNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a Dashboards type host group."""

    @abc.abstractmethod
    def UpdateDashboardsNodeGroup(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateDashboardsNodeGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates a Dashboards type host group."""

    @abc.abstractmethod
    def GetAuthSettings(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.GetAuthSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.auth_pb2.AuthSettings, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.auth_pb2.AuthSettings]]:
        """Retrieves auth settings for specified cluster."""

    @abc.abstractmethod
    def UpdateAuthSettings(
        self,
        request: yandex.cloud.mdb.opensearch.v1.cluster_service_pb2.UpdateAuthSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates auth settings for specified cluster."""

def add_ClusterServiceServicer_to_server(servicer: ClusterServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/vpc/v1/address.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x9c\x05\n\x07\x41\x64\x64ress\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x06labels\x18\x06 \x03(\x0b\x32(.yandex.cloud.vpc.v1.Address.LabelsEntry\x12I\n\x15\x65xternal_ipv4_address\x18\x07 \x01(\x0b\x32(.yandex.cloud.vpc.v1.ExternalIpv4AddressH\x00\x12\x10\n\x08reserved\x18\x0f \x01(\x08\x12\x0c\n\x04used\x18\x10 \x01(\x08\x12/\n\x04type\x18\x11 \x01(\x0e\x32!.yandex.cloud.vpc.v1.Address.Type\x12:\n\nip_version\x18\x12 \x01(\x0e\x32&.yandex.cloud.vpc.v1.Address.IpVersion\x12\x1b\n\x13\x64\x65letion_protection\x18\x13 \x01(\x08\x12\x33\n\x0b\x64ns_records\x18\x14 \x03(\x0b\x32\x1e.yandex.cloud.vpc.v1.DnsRecord\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\";\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42\x0f\n\x07\x61\x64\x64ress\x12\x04\xc0\xc1\x31\x01J\x04\x08\x08\x10\x0f\"w\n\x13\x45xternalIpv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07zone_id\x18\x02 \x01(\t\x12>\n\x0crequirements\x18\x03 \x01(\x0b\x32(.yandex.cloud.vpc.v1.AddressRequirements\"Y\n\x13\x41\x64\x64ressRequirements\x12 \n\x18\x64\x64os_protection_provider\x18\x01 \x01(\t\x12 \n\x18outgoing_smtp_capability\x18\x02 \x01(\t\"H\n\tDnsRecord\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x0b\n\x03ttl\x18\x03 \x01(\x03\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\x42V\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.address_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _ADDRESS_LABELSENTRY._options = None
  _ADDRESS_LABELSENTRY._serialized_options = b'8\001'
  _ADDRESS.oneofs_by_name['address']._options = None
  _ADDRESS.oneofs_by_name['address']._serialized_options = b'\300\3011\001'
  _globals['_ADDRESS']._serialized_start=123
  _globals['_ADDRESS']._serialized_end=791
  _globals['_ADDRESS_LABELSENTRY']._serialized_start=604
  _globals['_ADDRESS_LABELSENTRY']._serialized_end=649
  _globals['_ADDRESS_TYPE']._serialized_start=651
  _globals['_ADDRESS_TYPE']._serialized_end=707
  _globals['_ADDRESS_IPVERSION']._serialized_start=709
  _globals['_ADDRESS_IPVERSION']._serialized_end=768
  _globals['_EXTERNALIPV4ADDRESS']._serialized_start=793
  _globals['_EXTERNALIPV4ADDRESS']._serialized_end=912
  _globals['_ADDRESSREQUIREMENTS']._serialized_start=914
  _globals['_ADDRESSREQUIREMENTS']._serialized_end=1003
  _globals['_DNSRECORD']._serialized_start=1005
  _globals['_DNSRECORD']._serialized_end=1077
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/jobs/jobs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/datasphere/v2/jobs/jobs.proto\x12\x1fyandex.cloud.datasphere.v2.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc0\x05\n\rJobParameters\x12:\n\x0binput_files\x18\x01 \x03(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.File\x12?\n\x0coutput_files\x18\x02 \x03(\x0b\x32).yandex.cloud.datasphere.v2.jobs.FileDesc\x12\x14\n\x0cs3_mount_ids\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x61taset_ids\x18\x04 \x03(\t\x12\x0b\n\x03\x63md\x18\x05 \x01(\t\x12\x39\n\x03\x65nv\x18\x06 \x01(\x0b\x32,.yandex.cloud.datasphere.v2.jobs.Environment\x12\x1b\n\x13\x61ttach_project_disk\x18\x07 \x01(\x08\x12Y\n\x14\x63loud_instance_types\x18\x08 \x03(\x0b\x32\x32.yandex.cloud.datasphere.v2.jobs.CloudInstanceTypeB\x07\x82\xc8\x31\x03>=1\x12Y\n\x18\x65xtended_working_storage\x18\t \x01(\x0b\x32\x37.yandex.cloud.datasphere.v2.jobs.ExtendedWorkingStorage\x12<\n\targuments\x18\n \x03(\x0b\x32).yandex.cloud.datasphere.v2.jobs.Argument\x12K\n\x0foutput_datasets\x18\x0b \x03(\x0b\x32\x32.yandex.cloud.datasphere.v2.jobs.OutputDatasetDesc\x12\x61\n\x1cgraceful_shutdown_parameters\x18\x0c \x01(\x0b\x32;.yandex.cloud.datasphere.v2.jobs.GracefulShutdownParameters\"!\n\x11\x43loudInstanceType\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb2\x01\n\x16\x45xtendedWorkingStorage\x12Q\n\x04type\x18\x01 \x01(\x0e\x32\x43.yandex.cloud.datasphere.v2.jobs.ExtendedWorkingStorage.StorageType\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\"4\n\x0bStorageType\x12\x1c\n\x18STORAGE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03SSD\x10\x01\"\'\n\x08\x41rgument\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xb3\x01\n\x04\x46ile\x12\x37\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32).yandex.cloud.datasphere.v2.jobs.FileDesc\x12\x0e\n\x06sha256\x18\x02 \x01(\t\x12\x12\n\nsize_bytes\x18\x03 \x01(\x03\x12N\n\x10\x63ompression_type\x18\x04 \x01(\x0e\x32\x34.yandex.cloud.datasphere.v2.jobs.FileCompressionType\"O\n\x0bStorageFile\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.File\x12\x0b\n\x03url\x18\x02 \x01(\t\"%\n\x08\x46ileDesc\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0b\n\x03var\x18\x02 \x01(\t\"\xc3\x02\n\x0b\x45nvironment\x12\x44\n\x04vars\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.datasphere.v2.jobs.Environment.VarsEntry\x12\"\n\x18\x64ocker_image_resource_id\x18\x02 \x01(\tH\x00\x12M\n\x11\x64ocker_image_spec\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.datasphere.v2.jobs.DockerImageSpecH\x00\x12>\n\npython_env\x18\x04 \x01(\x0b\x32*.yandex.cloud.datasphere.v2.jobs.PythonEnv\x1a+\n\tVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0c\x64ocker_image\"\x84\x01\n\x0f\x44ockerImageSpec\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x1d\n\x13password_plain_text\x18\x03 \x01(\tH\x00\x12!\n\x17password_ds_secret_name\x18\x04 \x01(\tH\x00\x42\n\n\x08password\"]\n\tPythonEnv\x12\x12\n\nconda_yaml\x18\x01 \x01(\t\x12<\n\rlocal_modules\x18\x02 \x03(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.File\"\xd3\x01\n\x11OutputDatasetDesc\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12N\n\x06labels\x18\x03 \x03(\x0b\x32>.yandex.cloud.datasphere.v2.jobs.OutputDatasetDesc.LabelsEntry\x12\x0f\n\x07size_gb\x18\x04 \x01(\x03\x12\x0b\n\x03var\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\rOutputDataset\x12@\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datasphere.v2.jobs.OutputDatasetDesc\x12\n\n\x02id\x18\x02 \x01(\t\"\x99\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x06status\x18\x06 \x01(\x0e\x32*.yandex.cloud.datasphere.v2.jobs.JobStatus\x12\x0e\n\x06\x63onfig\x18\x07 \x01(\t\x12\x15\n\rcreated_by_id\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x46\n\x0ejob_parameters\x18\n \x01(\x0b\x32..yandex.cloud.datasphere.v2.jobs.JobParameters\x12\x33\n\x0f\x64\x61ta_expires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x64\x61ta_cleared\x18\x0c \x01(\x08\x12;\n\x0coutput_files\x18\r \x03(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.File\x12\x38\n\tlog_files\x18\x0e \x03(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.File\x12?\n\x10\x64iagnostic_files\x18\x0f \x03(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.File\x12\x17\n\x0f\x64\x61ta_size_bytes\x18\x10 \x01(\x03\" \n\tJobResult\x12\x13\n\x0breturn_code\x18\x01 \x01(\x03\"X\n\x1aGracefulShutdownParameters\x12*\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0e\n\x06signal\x18\x02 \x01(\x03*O\n\x13\x46ileCompressionType\x12%\n!FILE_COMPRESSION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03ZIP\x10\x02*\x91\x01\n\tJobStatus\x12\x1a\n\x16JOB_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x14\n\x10UPLOADING_OUTPUT\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\x0e\n\nCANCELLING\x10\x07\x42{\n#yandex.cloud.api.datasphere.v2.jobsB\x04JobsZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2/jobs;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.jobs.jobs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.datasphere.v2.jobsB\004JobsZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2/jobs;datasphere'
  _JOBPARAMETERS.fields_by_name['cloud_instance_types']._options = None
  _JOBPARAMETERS.fields_by_name['cloud_instance_types']._serialized_options = b'\202\3101\003>=1'
  _ENVIRONMENT_VARSENTRY._options = None
  _ENVIRONMENT_VARSENTRY._serialized_options = b'8\001'
  _OUTPUTDATASETDESC_LABELSENTRY._options = None
  _OUTPUTDATASETDESC_LABELSENTRY._serialized_options = b'8\001'
  _globals['_FILECOMPRESSIONTYPE']._serialized_start=3098
  _globals['_FILECOMPRESSIONTYPE']._serialized_end=3177
  _globals['_JOBSTATUS']._serialized_start=3180
  _globals['_JOBSTATUS']._serialized_end=3325
  _globals['_JOBPARAMETERS']._serialized_start=176
  _globals['_JOBPARAMETERS']._serialized_end=880
  _globals['_CLOUDINSTANCETYPE']._serialized_start=882
  _globals['_CLOUDINSTANCETYPE']._serialized_end=915
  _globals['_EXTENDEDWORKINGSTORAGE']._serialized_start=918
  _globals['_EXTENDEDWORKINGSTORAGE']._serialized_end=1096
  _globals['_EXTENDEDWORKINGSTORAGE_STORAGETYPE']._serialized_start=1044
  _globals['_EXTENDEDWORKINGSTORAGE_STORAGETYPE']._serialized_end=1096
  _globals['_ARGUMENT']._serialized_start=1098
  _globals['_ARGUMENT']._serialized_end=1137
  _globals['_FILE']._serialized_start=1140
  _globals['_FILE']._serialized_end=1319
  _globals['_STORAGEFILE']._serialized_start=1321
  _globals['_STORAGEFILE']._serialized_end=1400
  _globals['_FILEDESC']._serialized_start=1402
  _globals['_FILEDESC']._serialized_end=1439
  _globals['_ENVIRONMENT']._serialized_start=1442
  _globals['_ENVIRONMENT']._serialized_end=1765
  _globals['_ENVIRONMENT_VARSENTRY']._serialized_start=1706
  _globals['_ENVIRONMENT_VARSENTRY']._serialized_end=1749
  _globals['_DOCKERIMAGESPEC']._serialized_start=1768
  _globals['_DOCKERIMAGESPEC']._serialized_end=1900
  _globals['_PYTHONENV']._serialized_start=1902
  _globals['_PYTHONENV']._serialized_end=1995
  _globals['_OUTPUTDATASETDESC']._serialized_start=1998
  _globals['_OUTPUTDATASETDESC']._serialized_end=2209
  _globals['_OUTPUTDATASETDESC_LABELSENTRY']._serialized_start=2164
  _globals['_OUTPUTDATASETDESC_LABELSENTRY']._serialized_end=2209
  _globals['_OUTPUTDATASET']._serialized_start=2211
  _globals['_OUTPUTDATASET']._serialized_end=2304
  _globals['_JOB']._serialized_start=2307
  _globals['_JOB']._serialized_end=2972
  _globals['_JOBRESULT']._serialized_start=2974
  _globals['_JOBRESULT']._serialized_end=3006
  _globals['_GRACEFULSHUTDOWNPARAMETERS']._serialized_start=3008
  _globals['_GRACEFULSHUTDOWNPARAMETERS']._serialized_end=3096
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/redis/v1/config/redis6_2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/redis/v1/config/redis6_2.proto\x12 yandex.cloud.mdb.redis.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x98\t\n\x0eRedisConfig6_2\x12Z\n\x10maxmemory_policy\x18\x01 \x01(\x0e\x32@.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2.MaxmemoryPolicy\x12,\n\x07timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x08password\x18\x03 \x01(\tB&\xf2\xc7\x31\"[a-zA-Z0-9@=+?*.,!&#$^<>_-]{8,128}\x12\x36\n\tdatabases\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x45\n\x17slowlog_log_slower_than\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12=\n\x0fslowlog_max_len\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x16notify_keyspace_events\x18\x07 \x01(\tB\x19\xf2\xc7\x31\x15[KEg$lshzxeAtm]{0,13}\x12s\n!client_output_buffer_limit_pubsub\x18\x08 \x01(\x0b\x32H.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2.ClientOutputBufferLimit\x12s\n!client_output_buffer_limit_normal\x18\t \x01(\x0b\x32H.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2.ClientOutputBufferLimit\x12@\n\x11maxmemory_percent\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-75\x1a\xd5\x01\n\x17\x43lientOutputBufferLimit\x12\x38\n\nhard_limit\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x38\n\nsoft_limit\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x0csoft_seconds\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0J\x04\x08\x04\x10\x05J\x04\x08\x02\x10\x03\"\xc4\x01\n\x0fMaxmemoryPolicy\x12 \n\x1cMAXMEMORY_POLICY_UNSPECIFIED\x10\x00\x12\x10\n\x0cVOLATILE_LRU\x10\x01\x12\x0f\n\x0b\x41LLKEYS_LRU\x10\x02\x12\x10\n\x0cVOLATILE_LFU\x10\x03\x12\x0f\n\x0b\x41LLKEYS_LFU\x10\x04\x12\x13\n\x0fVOLATILE_RANDOM\x10\x05\x12\x12\n\x0e\x41LLKEYS_RANDOM\x10\x06\x12\x10\n\x0cVOLATILE_TTL\x10\x07\x12\x0e\n\nNOEVICTION\x10\x08\"\xf0\x01\n\x11RedisConfigSet6_2\x12J\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2\x12\x45\n\x0buser_config\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2\x12H\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2Br\n$yandex.cloud.api.mdb.redis.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1/config;redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.redis.v1.config.redis6_2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$yandex.cloud.api.mdb.redis.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1/config;redis'
  _REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT.fields_by_name['hard_limit']._options = None
  _REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT.fields_by_name['hard_limit']._serialized_options = b'\372\3071\003>=0'
  _REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT.fields_by_name['soft_limit']._options = None
  _REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT.fields_by_name['soft_limit']._serialized_options = b'\372\3071\003>=0'
  _REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT.fields_by_name['soft_seconds']._options = None
  _REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT.fields_by_name['soft_seconds']._serialized_options = b'\372\3071\003>=0'
  _REDISCONFIG6_2.fields_by_name['password']._options = None
  _REDISCONFIG6_2.fields_by_name['password']._serialized_options = b'\362\3071\"[a-zA-Z0-9@=+?*.,!&#$^<>_-]{8,128}'
  _REDISCONFIG6_2.fields_by_name['databases']._options = None
  _REDISCONFIG6_2.fields_by_name['databases']._serialized_options = b'\372\3071\002>0'
  _REDISCONFIG6_2.fields_by_name['slowlog_log_slower_than']._options = None
  _REDISCONFIG6_2.fields_by_name['slowlog_log_slower_than']._serialized_options = b'\372\3071\003>=0'
  _REDISCONFIG6_2.fields_by_name['slowlog_max_len']._options = None
  _REDISCONFIG6_2.fields_by_name['slowlog_max_len']._serialized_options = b'\372\3071\003>=0'
  _REDISCONFIG6_2.fields_by_name['notify_keyspace_events']._options = None
  _REDISCONFIG6_2.fields_by_name['notify_keyspace_events']._serialized_options = b'\362\3071\025[KEg$lshzxeAtm]{0,13}'
  _REDISCONFIG6_2.fields_by_name['maxmemory_percent']._options = None
  _REDISCONFIG6_2.fields_by_name['maxmemory_percent']._serialized_options = b'\372\3071\0041-75'
  _globals['_REDISCONFIG6_2']._serialized_start=149
  _globals['_REDISCONFIG6_2']._serialized_end=1325
  _globals['_REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT']._serialized_start=913
  _globals['_REDISCONFIG6_2_CLIENTOUTPUTBUFFERLIMIT']._serialized_end=1126
  _globals['_REDISCONFIG6_2_MAXMEMORYPOLICY']._serialized_start=1129
  _globals['_REDISCONFIG6_2_MAXMEMORYPOLICY']._serialized_end=1325
  _globals['_REDISCONFIGSET6_2']._serialized_start=1328
  _globals['_REDISCONFIGSET6_2']._serialized_end=1568
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Stream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _StreamStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StreamStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Stream._StreamStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STREAM_STATUS_UNSPECIFIED: Stream._StreamStatus.ValueType  # 0
        """Stream status unspecified."""
        OFFLINE: Stream._StreamStatus.ValueType  # 1
        """Stream offline."""
        PREPARING: Stream._StreamStatus.ValueType  # 2
        """Preparing the infrastructure for receiving video signal."""
        READY: Stream._StreamStatus.ValueType  # 3
        """Everything is ready to launch stream."""
        ONAIR: Stream._StreamStatus.ValueType  # 4
        """Stream onair."""
        FINISHED: Stream._StreamStatus.ValueType  # 5
        """Stream finished."""

    class StreamStatus(_StreamStatus, metaclass=_StreamStatusEnumTypeWrapper):
        """Stream status."""

    STREAM_STATUS_UNSPECIFIED: Stream.StreamStatus.ValueType  # 0
    """Stream status unspecified."""
    OFFLINE: Stream.StreamStatus.ValueType  # 1
    """Stream offline."""
    PREPARING: Stream.StreamStatus.ValueType  # 2
    """Preparing the infrastructure for receiving video signal."""
    READY: Stream.StreamStatus.ValueType  # 3
    """Everything is ready to launch stream."""
    ONAIR: Stream.StreamStatus.ValueType  # 4
    """Stream onair."""
    FINISHED: Stream.StreamStatus.ValueType  # 5
    """Stream finished."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    PUBLISH_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    ON_DEMAND_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the stream."""
    channel_id: builtins.str
    """ID of the channel where the stream was created."""
    line_id: builtins.str
    """ID of the line to which stream is linked."""
    title: builtins.str
    """Stream title."""
    description: builtins.str
    """Stream description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    status: global___Stream.StreamStatus.ValueType
    """Stream status."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Stream start time."""

    @property
    def publish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Stream publish time. Time when stream switched to ONAIR status."""

    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Stream finish time."""

    @property
    def on_demand(self) -> global___OnDemand:
        """On demand stream. It starts immediately when a signal appears."""

    @property
    def schedule(self) -> global___Schedule:
        """Schedule stream. Determines when to start receiving the signal or finish time."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when stream was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last stream update."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        status: global___Stream.StreamStatus.ValueType = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        publish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        on_demand: global___OnDemand | None = ...,
        schedule: global___Schedule | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "finish_time", b"finish_time", "on_demand", b"on_demand", "publish_time", b"publish_time", "schedule", b"schedule", "start_time", b"start_time", "stream_type", b"stream_type", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "created_at", b"created_at", "description", b"description", "finish_time", b"finish_time", "id", b"id", "labels", b"labels", "line_id", b"line_id", "on_demand", b"on_demand", "publish_time", b"publish_time", "schedule", b"schedule", "start_time", b"start_time", "status", b"status", "stream_type", b"stream_type", "thumbnail_id", b"thumbnail_id", "title", b"title", "updated_at", b"updated_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["stream_type", b"stream_type"]) -> typing.Literal["on_demand", "schedule"] | None: ...

global___Stream = Stream

@typing.final
class OnDemand(google.protobuf.message.Message):
    """If "OnDemand" is used, client should start and finish explicitly."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OnDemand = OnDemand

@typing.final
class Schedule(google.protobuf.message.Message):
    """If "Schedule" is used, stream automatically start and finish at this time."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["finish_time", b"finish_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["finish_time", b"finish_time", "start_time", b"start_time"]) -> None: ...

global___Schedule = Schedule



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.dns.v1.dns_zone_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UpdateDnsZonePrivateNetworksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    PRIVATE_NETWORK_ID_ADDITIONS_FIELD_NUMBER: builtins.int
    PRIVATE_NETWORK_ID_DELETIONS_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone which private networks will be updated"""
    @property
    def private_network_id_additions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Network IDs to remove"""

    @property
    def private_network_id_deletions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Network IDs to add"""

    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        private_network_id_additions: collections.abc.Iterable[builtins.str] | None = ...,
        private_network_id_deletions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "private_network_id_additions", b"private_network_id_additions", "private_network_id_deletions", b"private_network_id_deletions"]) -> None: ...

global___UpdateDnsZonePrivateNetworksRequest = UpdateDnsZonePrivateNetworksRequest

@typing.final
class UpdateDnsZonePrivateNetworksMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone which private networks was updated"""
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id"]) -> None: ...

global___UpdateDnsZonePrivateNetworksMetadata = UpdateDnsZonePrivateNetworksMetadata

@typing.final
class GetDnsZoneRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to return.

    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id"]) -> None: ...

global___GetDnsZoneRequest = GetDnsZoneRequest

@typing.final
class ListDnsZonesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list DNS zones in. 

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListDnsZonesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListDnsZonesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters DNS zones listed in the response.

    The expression must specify: 
    1. The field name. Currently you can use filtering only on the [DnsZone.name] field. 
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-dns-zone`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDnsZonesRequest = ListDnsZonesRequest

@typing.final
class ListDnsZonesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDnsZonesRequest.page_size], use `next_page_token` as the value
    for the [ListDnsZonesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def dns_zones(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.DnsZone]:
        """List of DNS zones in the specified folder."""

    def __init__(
        self,
        *,
        dns_zones: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.DnsZone] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zones", b"dns_zones", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDnsZonesResponse = ListDnsZonesResponse

@typing.final
class CreateDnsZoneRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    PRIVATE_VISIBILITY_FIELD_NUMBER: builtins.int
    PUBLIC_VISIBILITY_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create DNS zones in.

    To get a folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the DNS zone. 
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the DNS zone."""
    zone: builtins.str
    """DNS zone suffix."""
    deletion_protection: builtins.bool
    """Prevents accidental zone removal."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """DNS zone labels as `key:value` pairs."""

    @property
    def private_visibility(self) -> yandex.cloud.dns.v1.dns_zone_pb2.PrivateVisibility:
        """Privately visible zone settings. 
        At least one of two visibility fields must be set.
        """

    @property
    def public_visibility(self) -> yandex.cloud.dns.v1.dns_zone_pb2.PublicVisibility:
        """Publicly visible zone settings.
        At least one of two visibility fields must be set.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone: builtins.str = ...,
        private_visibility: yandex.cloud.dns.v1.dns_zone_pb2.PrivateVisibility | None = ...,
        public_visibility: yandex.cloud.dns.v1.dns_zone_pb2.PublicVisibility | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["private_visibility", b"private_visibility", "public_visibility", b"public_visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "private_visibility", b"private_visibility", "public_visibility", b"public_visibility", "zone", b"zone"]) -> None: ...

global___CreateDnsZoneRequest = CreateDnsZoneRequest

@typing.final
class CreateDnsZoneMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone that is being created."""
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id"]) -> None: ...

global___CreateDnsZoneMetadata = CreateDnsZoneMetadata

@typing.final
class UpdateDnsZoneRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PRIVATE_VISIBILITY_FIELD_NUMBER: builtins.int
    PUBLIC_VISIBILITY_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to update.
     
    To get the DNS zone ID, make a [DnsZoneService.List] request.
    """
    name: builtins.str
    """New name for the DNS zone. 
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the DNS zone."""
    deletion_protection: builtins.bool
    """Prevents accidental zone removal."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the DNS zone resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """DNS zone labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [DnsZoneService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def private_visibility(self) -> yandex.cloud.dns.v1.dns_zone_pb2.PrivateVisibility:
        """Change network IDs for private visibility."""

    @property
    def public_visibility(self) -> yandex.cloud.dns.v1.dns_zone_pb2.PublicVisibility:
        """Public visibility configuration."""

    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        private_visibility: yandex.cloud.dns.v1.dns_zone_pb2.PrivateVisibility | None = ...,
        public_visibility: yandex.cloud.dns.v1.dns_zone_pb2.PublicVisibility | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["private_visibility", b"private_visibility", "public_visibility", b"public_visibility", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "dns_zone_id", b"dns_zone_id", "labels", b"labels", "name", b"name", "private_visibility", b"private_visibility", "public_visibility", b"public_visibility", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDnsZoneRequest = UpdateDnsZoneRequest

@typing.final
class UpdateDnsZoneMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone that is being updated."""
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id"]) -> None: ...

global___UpdateDnsZoneMetadata = UpdateDnsZoneMetadata

@typing.final
class DeleteDnsZoneRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to delete.

    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id"]) -> None: ...

global___DeleteDnsZoneRequest = DeleteDnsZoneRequest

@typing.final
class DeleteDnsZoneMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone that is being deleted."""
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id"]) -> None: ...

global___DeleteDnsZoneMetadata = DeleteDnsZoneMetadata

@typing.final
class GetDnsZoneRecordSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to get record set from.

    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    name: builtins.str
    """Name of the record set."""
    type: builtins.str
    """Type of the record set."""
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "name", b"name", "type", b"type"]) -> None: ...

global___GetDnsZoneRecordSetRequest = GetDnsZoneRecordSetRequest

@typing.final
class ListDnsZoneRecordSetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to list record sets in. 

    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListDnsZoneRecordSetsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListDnsZoneRecordSetsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters record sets listed in the response. The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where: 
    1. `<field>` is the field name. Currently you can use filtering only on the [RecordSet.name] and [RecordSet.type] fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    3.1. In case of single value condition (`=` or `!=`), the value is a string in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    3.2. In case of a list of values condition (`IN` or `NOT IN`), the value is `(<string1>, <string2>, .., <stringN>)`, where `<string>` is a string in double (`"`) or single (`'`) quotes.

    Examples of a filter: `name="my-record-set"`, `type IN ("MX","A") AND name="works.on.my.machine."`.
    """
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDnsZoneRecordSetsRequest = ListDnsZoneRecordSetsRequest

@typing.final
class ListDnsZoneRecordSetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_SETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDnsZoneRecordSetsRequest.page_size], use `next_page_token` as the value
    for the [ListDnsZoneRecordSetsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def record_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """List of record sets in the specified DNS zone."""

    def __init__(
        self,
        *,
        record_sets: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "record_sets", b"record_sets"]) -> None: ...

global___ListDnsZoneRecordSetsResponse = ListDnsZoneRecordSetsResponse

@typing.final
class UpdateRecordSetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    DELETIONS_FIELD_NUMBER: builtins.int
    ADDITIONS_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to update record sets in.
     
    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    @property
    def deletions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """List of record sets to delete."""

    @property
    def additions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """List of record sets to add."""

    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        deletions: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
        additions: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["additions", b"additions", "deletions", b"deletions", "dns_zone_id", b"dns_zone_id"]) -> None: ...

global___UpdateRecordSetsRequest = UpdateRecordSetsRequest

@typing.final
class UpdateRecordSetsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateRecordSetsMetadata = UpdateRecordSetsMetadata

@typing.final
class UpsertRecordSetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    DELETIONS_FIELD_NUMBER: builtins.int
    REPLACEMENTS_FIELD_NUMBER: builtins.int
    MERGES_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to upsert record sets to.
     
    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    @property
    def deletions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """Delete only specified records from corresponding record sets."""

    @property
    def replacements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """Entirely replace specified record sets."""

    @property
    def merges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """Replace specified records or add new ones if no such record sets exists."""

    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        deletions: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
        replacements: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
        merges: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deletions", b"deletions", "dns_zone_id", b"dns_zone_id", "merges", b"merges", "replacements", b"replacements"]) -> None: ...

global___UpsertRecordSetsRequest = UpsertRecordSetsRequest

@typing.final
class UpsertRecordSetsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpsertRecordSetsMetadata = UpsertRecordSetsMetadata

@typing.final
class RecordSetDiff(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONS_FIELD_NUMBER: builtins.int
    DELETIONS_FIELD_NUMBER: builtins.int
    @property
    def additions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """List of record sets that were added"""

    @property
    def deletions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet]:
        """List of record sets that were deleted"""

    def __init__(
        self,
        *,
        additions: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
        deletions: collections.abc.Iterable[yandex.cloud.dns.v1.dns_zone_pb2.RecordSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["additions", b"additions", "deletions", b"deletions"]) -> None: ...

global___RecordSetDiff = RecordSetDiff

@typing.final
class ListDnsZoneOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    dns_zone_id: builtins.str
    """ID of the DNS zone to list operations for.

    To get a DNS zone ID, make a [DnsZoneService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDnsZoneOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the 
    [ListDnsZoneOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters DNS zones listed in the response.

    The expression must specify: 
    1. The field name. Currently you can use filtering only on the [DnsZone.name] field. 
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-dns-zone`.
    """
    def __init__(
        self,
        *,
        dns_zone_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDnsZoneOperationsRequest = ListDnsZoneOperationsRequest

@typing.final
class ListDnsZoneOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDnsZoneOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListDnsZoneOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified DNS zone."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDnsZoneOperationsResponse = ListDnsZoneOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class QuotaMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """formatted as <domain>.<metric>.<unit>, e.g. mdb.hdd.size"""
    limit: builtins.int
    usage: builtins.float
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        limit: builtins.int = ...,
        usage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["limit", b"limit", "name", b"name", "usage", b"usage"]) -> None: ...

global___QuotaMetric = QuotaMetric

@typing.final
class MetricLimit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    name: builtins.str
    limit: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["limit", b"limit", "name", b"name"]) -> None: ...

global___MetricLimit = MetricLimit

@typing.final
class QuotaFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Violation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        METRIC_FIELD_NUMBER: builtins.int
        REQUIRED_FIELD_NUMBER: builtins.int
        required: builtins.int
        """new value for the MetricLimit.limit, so it is: old limit + delta"""
        @property
        def metric(self) -> global___QuotaMetric: ...
        def __init__(
            self,
            *,
            metric: global___QuotaMetric | None = ...,
            required: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["metric", b"metric"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["metric", b"metric", "required", b"required"]) -> None: ...

    VIOLATIONS_FIELD_NUMBER: builtins.int
    @property
    def violations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QuotaFailure.Violation]: ...
    def __init__(
        self,
        *,
        violations: collections.abc.Iterable[global___QuotaFailure.Violation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["violations", b"violations"]) -> None: ...

global___QuotaFailure = QuotaFailure



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BudgetStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BudgetStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BudgetStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BUDGET_STATUS_UNSPECIFIED: _BudgetStatus.ValueType  # 0
    CREATING: _BudgetStatus.ValueType  # 1
    """The budget is being created."""
    ACTIVE: _BudgetStatus.ValueType  # 2
    """The budget is active."""
    FINISHED: _BudgetStatus.ValueType  # 3
    """The budget is finished."""

class BudgetStatus(_BudgetStatus, metaclass=_BudgetStatusEnumTypeWrapper): ...

BUDGET_STATUS_UNSPECIFIED: BudgetStatus.ValueType  # 0
CREATING: BudgetStatus.ValueType  # 1
"""The budget is being created."""
ACTIVE: BudgetStatus.ValueType  # 2
"""The budget is active."""
FINISHED: BudgetStatus.ValueType  # 3
"""The budget is finished."""
global___BudgetStatus = BudgetStatus

class _ResetPeriodType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResetPeriodTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResetPeriodType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESET_PERIOD_TYPE_UNSPECIFIED: _ResetPeriodType.ValueType  # 0
    MONTHLY: _ResetPeriodType.ValueType  # 1
    """Reset budget every month."""
    QUARTER: _ResetPeriodType.ValueType  # 2
    """Reset budget every quarter."""
    ANNUALLY: _ResetPeriodType.ValueType  # 3
    """Reset budget every year."""

class ResetPeriodType(_ResetPeriodType, metaclass=_ResetPeriodTypeEnumTypeWrapper): ...

RESET_PERIOD_TYPE_UNSPECIFIED: ResetPeriodType.ValueType  # 0
MONTHLY: ResetPeriodType.ValueType  # 1
"""Reset budget every month."""
QUARTER: ResetPeriodType.ValueType  # 2
"""Reset budget every quarter."""
ANNUALLY: ResetPeriodType.ValueType  # 3
"""Reset budget every year."""
global___ResetPeriodType = ResetPeriodType

class _ThresholdType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThresholdTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThresholdType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    THRESHOLD_TYPE_UNSPECIFIED: _ThresholdType.ValueType  # 0
    PERCENT: _ThresholdType.ValueType  # 1
    """Percent."""
    AMOUNT: _ThresholdType.ValueType  # 2
    """The same as budget amount."""

class ThresholdType(_ThresholdType, metaclass=_ThresholdTypeEnumTypeWrapper):
    """Define the unit of the [ThesholdRule.amount]."""

THRESHOLD_TYPE_UNSPECIFIED: ThresholdType.ValueType  # 0
PERCENT: ThresholdType.ValueType  # 1
"""Percent."""
AMOUNT: ThresholdType.ValueType  # 2
"""The same as budget amount."""
global___ThresholdType = ThresholdType

@typing.final
class Budget(google.protobuf.message.Message):
    """A Budget resource. For more information, see [/docs/billing/concepts/budget]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    COST_BUDGET_FIELD_NUMBER: builtins.int
    EXPENSE_BUDGET_FIELD_NUMBER: builtins.int
    BALANCE_BUDGET_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the budget."""
    name: builtins.str
    """Name of the budget."""
    billing_account_id: builtins.str
    """ID of the billing account that the budget belongs to."""
    status: global___BudgetStatus.ValueType
    """Status of the budget."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def cost_budget(self) -> global___CostBudgetSpec:
        """Cost budget specification."""

    @property
    def expense_budget(self) -> global___ExpenseBudgetSpec:
        """Expense budget specification."""

    @property
    def balance_budget(self) -> global___BalanceBudgetSpec:
        """Balance budget specification."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        billing_account_id: builtins.str = ...,
        status: global___BudgetStatus.ValueType = ...,
        cost_budget: global___CostBudgetSpec | None = ...,
        expense_budget: global___ExpenseBudgetSpec | None = ...,
        balance_budget: global___BalanceBudgetSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["balance_budget", b"balance_budget", "budget_spec", b"budget_spec", "cost_budget", b"cost_budget", "created_at", b"created_at", "expense_budget", b"expense_budget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["balance_budget", b"balance_budget", "billing_account_id", b"billing_account_id", "budget_spec", b"budget_spec", "cost_budget", b"cost_budget", "created_at", b"created_at", "expense_budget", b"expense_budget", "id", b"id", "name", b"name", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["budget_spec", b"budget_spec"]) -> typing.Literal["cost_budget", "expense_budget", "balance_budget"] | None: ...

global___Budget = Budget

@typing.final
class CostBudgetSpec(google.protobuf.message.Message):
    """Cost budget specification describes budget that can be used to control cost of cloud resources usage."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    NOTIFICATION_USER_ACCOUNT_IDS_FIELD_NUMBER: builtins.int
    THRESHOLD_RULES_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    RESET_PERIOD_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    amount: builtins.str
    """Max cost threshold of the budget. Amount currency is the same as corresponding [yandex.cloud.billing.v1.BillingAccount.currency]."""
    reset_period: global___ResetPeriodType.ValueType
    """Periodic start type that resets budget after specified period is finished.
    First time budget is calculated in the current period, i.e. current month, quarter or year.
    """
    start_date: builtins.str
    """Custom start date of the budget.
    Must be the first day of a month and must be formatted like YYYY-MM-DD.
    """
    end_date: builtins.str
    """End date of the budget.
    Must be the last day of a month and must be formatted like YYYY-MM-DD.
    """
    @property
    def notification_user_account_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the [yandex.cloud.iam.v1.UserAccount].
        Specified users will be be notified if the budget exceeds.
        """

    @property
    def threshold_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThresholdRule]:
        """List of the [ThresholdRule].
        Rules define intermediate cost thresholds of the budget.
        """

    @property
    def filter(self) -> global___ConsumptionFilter:
        """Filter that can be used for specific resources selection. Only consumption cost of selected resources are used for the budget calculation."""

    def __init__(
        self,
        *,
        amount: builtins.str = ...,
        notification_user_account_ids: collections.abc.Iterable[builtins.str] | None = ...,
        threshold_rules: collections.abc.Iterable[global___ThresholdRule] | None = ...,
        filter: global___ConsumptionFilter | None = ...,
        reset_period: global___ResetPeriodType.ValueType = ...,
        start_date: builtins.str = ...,
        end_date: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter", "reset_period", b"reset_period", "start_date", b"start_date", "start_type", b"start_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["amount", b"amount", "end_date", b"end_date", "filter", b"filter", "notification_user_account_ids", b"notification_user_account_ids", "reset_period", b"reset_period", "start_date", b"start_date", "start_type", b"start_type", "threshold_rules", b"threshold_rules"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["start_type", b"start_type"]) -> typing.Literal["reset_period", "start_date"] | None: ...

global___CostBudgetSpec = CostBudgetSpec

@typing.final
class ExpenseBudgetSpec(google.protobuf.message.Message):
    """Expense budget specification describes budget that can be used to control expense of cloud resources usage."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    NOTIFICATION_USER_ACCOUNT_IDS_FIELD_NUMBER: builtins.int
    THRESHOLD_RULES_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    RESET_PERIOD_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    amount: builtins.str
    """Max expense threshold of the budget. Amount currency is the same as corresponding [yandex.cloud.billing.v1.BillingAccount.currency]."""
    reset_period: global___ResetPeriodType.ValueType
    """Periodic start type that resets budget after specified period is finished.
    First time budget is calculated in the current period, i.e. current month, quarter or year.
    """
    start_date: builtins.str
    """Custom start date of the budget.
    Must be the first day of a month and must be formatted like YYYY-MM-DD.
    """
    end_date: builtins.str
    """End date of the budget.
    Must be the last day of a month and must be formatted like YYYY-MM-DD.
    """
    @property
    def notification_user_account_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the [yandex.cloud.iam.v1.UserAccount].
        Specified users will be be notified if the budget exceeds.
        """

    @property
    def threshold_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThresholdRule]:
        """List of the [ThresholdRule].
        Rules define intermediate expense thresholds of the budget.
        """

    @property
    def filter(self) -> global___ConsumptionFilter:
        """Filter that can be used for specific resources selection. Only consumption expense of selected resources are used for the budget calculation."""

    def __init__(
        self,
        *,
        amount: builtins.str = ...,
        notification_user_account_ids: collections.abc.Iterable[builtins.str] | None = ...,
        threshold_rules: collections.abc.Iterable[global___ThresholdRule] | None = ...,
        filter: global___ConsumptionFilter | None = ...,
        reset_period: global___ResetPeriodType.ValueType = ...,
        start_date: builtins.str = ...,
        end_date: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter", "reset_period", b"reset_period", "start_date", b"start_date", "start_type", b"start_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["amount", b"amount", "end_date", b"end_date", "filter", b"filter", "notification_user_account_ids", b"notification_user_account_ids", "reset_period", b"reset_period", "start_date", b"start_date", "start_type", b"start_type", "threshold_rules", b"threshold_rules"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["start_type", b"start_type"]) -> typing.Literal["reset_period", "start_date"] | None: ...

global___ExpenseBudgetSpec = ExpenseBudgetSpec

@typing.final
class BalanceBudgetSpec(google.protobuf.message.Message):
    """Balance budget specification describes budget that can be used to control [yandex.cloud.billing.v1.BillingAccount.balance]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    NOTIFICATION_USER_ACCOUNT_IDS_FIELD_NUMBER: builtins.int
    THRESHOLD_RULES_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    amount: builtins.str
    """Max balance threshold of the budget. Amount currency is the same as corresponding [yandex.cloud.billing.v1.BillingAccount.currency]."""
    start_date: builtins.str
    """Start_date of the budget.
    Must be the first day of a month and must be formatted like YYYY-MM-DD.
    """
    end_date: builtins.str
    """End date of the budget.
    Must be the last day of a month and must be formatted like YYYY-MM-DD.
    """
    @property
    def notification_user_account_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the [yandex.cloud.iam.v1.UserAccount].
        Specified users will be be notified if the budget exceeds.
        """

    @property
    def threshold_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThresholdRule]:
        """List of the [ThresholdRule].
        Rules define intermediate balance thresholds of the budget.
        """

    def __init__(
        self,
        *,
        amount: builtins.str = ...,
        notification_user_account_ids: collections.abc.Iterable[builtins.str] | None = ...,
        threshold_rules: collections.abc.Iterable[global___ThresholdRule] | None = ...,
        start_date: builtins.str = ...,
        end_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["amount", b"amount", "end_date", b"end_date", "notification_user_account_ids", b"notification_user_account_ids", "start_date", b"start_date", "threshold_rules", b"threshold_rules"]) -> None: ...

global___BalanceBudgetSpec = BalanceBudgetSpec

@typing.final
class ConsumptionFilter(google.protobuf.message.Message):
    """Filter that can be used for specific resources selection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_IDS_FIELD_NUMBER: builtins.int
    CLOUD_FOLDERS_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def service_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the [yandex.cloud.billing.v1.Service].
        Only consumption of resources corresponding to the given services is used for the budget calculation.
        Empty sequence means no services filters.
        """

    @property
    def cloud_folders_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFoldersConsumptionFilter]:
        """Cloud and folders consumption filter.
        Only consumption within specified clouds and folders is used for the budget calculation.
        Empty sequence means no cloud and folders filters.
        """

    def __init__(
        self,
        *,
        service_ids: collections.abc.Iterable[builtins.str] | None = ...,
        cloud_folders_filters: collections.abc.Iterable[global___CloudFoldersConsumptionFilter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_folders_filters", b"cloud_folders_filters", "service_ids", b"service_ids"]) -> None: ...

global___ConsumptionFilter = ConsumptionFilter

@typing.final
class CloudFoldersConsumptionFilter(google.protobuf.message.Message):
    """Filter that can be used for specific cloud and its folders selection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_IDS_FIELD_NUMBER: builtins.int
    cloud_id: builtins.str
    """ID of the [yandex.cloud.resourcemanager.v1.Cloud].
    Only consumption within specified cloud is used for the budget calculation.
    """
    @property
    def folder_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the [yandex.cloud.resourcemanager.v1.Folder].
        Only consumption within specified folders of the given cloud is used for the budget calculation.
        Empty sequence means no folders filters and the whole cloud consumption will be used.
        """

    def __init__(
        self,
        *,
        cloud_id: builtins.str = ...,
        folder_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "folder_ids", b"folder_ids"]) -> None: ...

global___CloudFoldersConsumptionFilter = CloudFoldersConsumptionFilter

@typing.final
class ThresholdRule(google.protobuf.message.Message):
    """Rules that define intermediate cost thresholds of the budget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    NOTIFICATION_USER_ACCOUNT_IDS_FIELD_NUMBER: builtins.int
    type: global___ThresholdType.ValueType
    """Type of the rule."""
    amount: builtins.str
    """Amount of the rule.
     * Must be less than 100 if type is PERCENT.
     * Must be less than budget's amount if type is AMOUNT.
    """
    @property
    def notification_user_account_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the [yandex.cloud.iam.v1.UserAccount].
        Specified users will be be notified if the threshold exceeds.
        """

    def __init__(
        self,
        *,
        type: global___ThresholdType.ValueType = ...,
        amount: builtins.str = ...,
        notification_user_account_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["amount", b"amount", "notification_user_account_ids", b"notification_user_account_ids", "type", b"type"]) -> None: ...

global___ThresholdRule = ThresholdRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/backend_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import backend_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/apploadbalancer/v1/backend_group_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x33yandex/cloud/apploadbalancer/v1/backend_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x16GetBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x18ListBackendGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"{\n\x19ListBackendGroupsResponse\x12\x45\n\x0e\x62\x61\x63kend_groups\x18\x01 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.BackendGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x19\x44\x65leteBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1a\x44\x65leteBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\xed\x04\n\x19UpdateBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x41\n\x04http\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x12\x45\n\x06stream\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.StreamBackendGroupH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"6\n\x1aUpdateBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\xaf\x04\n\x19\x43reateBackendGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x41\n\x04http\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x12\x45\n\x06stream\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.StreamBackendGroupH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x62\x61\x63kend\"6\n\x1a\x43reateBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\x88\x02\n\x11\x41\x64\x64\x42\x61\x63kendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x04http\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackendH\x00\x12<\n\x04grpc\x18\x03 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackendH\x00\x12@\n\x06stream\x18\x05 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackendH\x00\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01J\x04\x08\x04\x10\x05\"D\n\x12\x41\x64\x64\x42\x61\x63kendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"\xb6\x02\n\x14UpdateBackendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04http\x18\x03 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackendH\x00\x12<\n\x04grpc\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackendH\x00\x12@\n\x06stream\x18\x05 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackendH\x00\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"G\n\x15UpdateBackendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"R\n\x14RemoveBackendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"G\n\x15RemoveBackendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"\x89\x01\n!ListBackendGroupOperationsRequest\x12&\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListBackendGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf1\x0e\n\x13\x42\x61\x63kendGroupService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.apploadbalancer.v1.GetBackendGroupRequest\x1a-.yandex.cloud.apploadbalancer.v1.BackendGroup\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/apploadbalancer/v1/backendGroups/{backend_group_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest\x1a:.yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/apploadbalancer/v1/backendGroups\x12\xc3\x01\n\x06\x43reate\x12:.yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2**\n\x1a\x43reateBackendGroupMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02&\"!/apploadbalancer/v1/backendGroups:\x01*\x12\xd6\x01\n\x06Update\x12:.yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2**\n\x1aUpdateBackendGroupMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02\x39\x32\x34/apploadbalancer/v1/backendGroups/{backend_group_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12:.yandex.cloud.apploadbalancer.v1.DeleteBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*3\n\x1a\x44\x65leteBackendGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/apploadbalancer/v1/backendGroups/{backend_group_id}\x12\xd5\x01\n\nAddBackend\x12\x32.yandex.cloud.apploadbalancer.v1.AddBackendRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*\"\n\x12\x41\x64\x64\x42\x61\x63kendMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02\x44\"?/apploadbalancer/v1/backendGroups/{backend_group_id}:addBackend:\x01*\x12\xe1\x01\n\rRemoveBackend\x12\x35.yandex.cloud.apploadbalancer.v1.RemoveBackendRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*%\n\x15RemoveBackendMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:removeBackend:\x01*\x12\xe1\x01\n\rUpdateBackend\x12\x35.yandex.cloud.apploadbalancer.v1.UpdateBackendRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*%\n\x15UpdateBackendMetadata\x12\x0c\x42\x61\x63kendGroup\x82\xd3\xe4\x93\x02G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:updateBackend:\x01*\x12\xe2\x01\n\x0eListOperations\x12\x42.yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest\x1a\x43.yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/apploadbalancer/v1/backendGroups/{backend_group_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _GETBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
  _GETBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTBACKENDGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTBACKENDGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _DELETEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
  _DELETEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _UPDATEBACKENDGROUPREQUEST_LABELSENTRY._options = None
  _UPDATEBACKENDGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']._options = None
  _UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']._serialized_options = b'\300\3011\001'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEBACKENDGROUPREQUEST_LABELSENTRY._options = None
  _CREATEBACKENDGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['folder_id']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['name']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['description']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEBACKENDGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATEBACKENDGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _ADDBACKENDREQUEST.oneofs_by_name['backend']._options = None
  _ADDBACKENDREQUEST.oneofs_by_name['backend']._serialized_options = b'\300\3011\001'
  _ADDBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
  _ADDBACKENDREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _UPDATEBACKENDREQUEST.oneofs_by_name['backend']._options = None
  _UPDATEBACKENDREQUEST.oneofs_by_name['backend']._serialized_options = b'\300\3011\001'
  _UPDATEBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
  _UPDATEBACKENDREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _REMOVEBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
  _REMOVEBACKENDREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _REMOVEBACKENDREQUEST.fields_by_name['backend_name']._options = None
  _REMOVEBACKENDREQUEST.fields_by_name['backend_name']._serialized_options = b'\350\3071\001'
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['backend_group_id']._options = None
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _BACKENDGROUPSERVICE.methods_by_name['Get']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/apploadbalancer/v1/backendGroups/{backend_group_id}'
  _BACKENDGROUPSERVICE.methods_by_name['List']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/apploadbalancer/v1/backendGroups'
  _BACKENDGROUPSERVICE.methods_by_name['Create']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateBackendGroupMetadata\022\014BackendGroup\202\323\344\223\002&\"!/apploadbalancer/v1/backendGroups:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['Update']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateBackendGroupMetadata\022\014BackendGroup\202\323\344\223\002924/apploadbalancer/v1/backendGroups/{backend_group_id}:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['Delete']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteBackendGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/apploadbalancer/v1/backendGroups/{backend_group_id}'
  _BACKENDGROUPSERVICE.methods_by_name['AddBackend']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['AddBackend']._serialized_options = b'\262\322*\"\n\022AddBackendMetadata\022\014BackendGroup\202\323\344\223\002D\"?/apploadbalancer/v1/backendGroups/{backend_group_id}:addBackend:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['RemoveBackend']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['RemoveBackend']._serialized_options = b'\262\322*%\n\025RemoveBackendMetadata\022\014BackendGroup\202\323\344\223\002G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:removeBackend:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['UpdateBackend']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['UpdateBackend']._serialized_options = b'\262\322*%\n\025UpdateBackendMetadata\022\014BackendGroup\202\323\344\223\002G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:updateBackend:\001*'
  _BACKENDGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _BACKENDGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/apploadbalancer/v1/backendGroups/{backend_group_id}/operations'
  _globals['_GETBACKENDGROUPREQUEST']._serialized_start=318
  _globals['_GETBACKENDGROUPREQUEST']._serialized_end=374
  _globals['_LISTBACKENDGROUPSREQUEST']._serialized_start=377
  _globals['_LISTBACKENDGROUPSREQUEST']._serialized_end=518
  _globals['_LISTBACKENDGROUPSRESPONSE']._serialized_start=520
  _globals['_LISTBACKENDGROUPSRESPONSE']._serialized_end=643
  _globals['_DELETEBACKENDGROUPREQUEST']._serialized_start=645
  _globals['_DELETEBACKENDGROUPREQUEST']._serialized_end=704
  _globals['_DELETEBACKENDGROUPMETADATA']._serialized_start=706
  _globals['_DELETEBACKENDGROUPMETADATA']._serialized_end=760
  _globals['_UPDATEBACKENDGROUPREQUEST']._serialized_start=763
  _globals['_UPDATEBACKENDGROUPREQUEST']._serialized_end=1384
  _globals['_UPDATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_start=1322
  _globals['_UPDATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_end=1367
  _globals['_UPDATEBACKENDGROUPMETADATA']._serialized_start=1386
  _globals['_UPDATEBACKENDGROUPMETADATA']._serialized_end=1440
  _globals['_CREATEBACKENDGROUPREQUEST']._serialized_start=1443
  _globals['_CREATEBACKENDGROUPREQUEST']._serialized_end=2002
  _globals['_CREATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_start=1322
  _globals['_CREATEBACKENDGROUPREQUEST_LABELSENTRY']._serialized_end=1367
  _globals['_CREATEBACKENDGROUPMETADATA']._serialized_start=2004
  _globals['_CREATEBACKENDGROUPMETADATA']._serialized_end=2058
  _globals['_ADDBACKENDREQUEST']._serialized_start=2061
  _globals['_ADDBACKENDREQUEST']._serialized_end=2325
  _globals['_ADDBACKENDMETADATA']._serialized_start=2327
  _globals['_ADDBACKENDMETADATA']._serialized_end=2395
  _globals['_UPDATEBACKENDREQUEST']._serialized_start=2398
  _globals['_UPDATEBACKENDREQUEST']._serialized_end=2708
  _globals['_UPDATEBACKENDMETADATA']._serialized_start=2710
  _globals['_UPDATEBACKENDMETADATA']._serialized_end=2781
  _globals['_REMOVEBACKENDREQUEST']._serialized_start=2783
  _globals['_REMOVEBACKENDREQUEST']._serialized_end=2865
  _globals['_REMOVEBACKENDMETADATA']._serialized_start=2867
  _globals['_REMOVEBACKENDMETADATA']._serialized_end=2938
  _globals['_LISTBACKENDGROUPOPERATIONSREQUEST']._serialized_start=2941
  _globals['_LISTBACKENDGROUPOPERATIONSREQUEST']._serialized_end=3078
  _globals['_LISTBACKENDGROUPOPERATIONSRESPONSE']._serialized_start=3080
  _globals['_LISTBACKENDGROUPOPERATIONSRESPONSE']._serialized_end=3196
  _globals['_BACKENDGROUPSERVICE']._serialized_start=3199
  _globals['_BACKENDGROUPSERVICE']._serialized_end=5104
# @@protoc_insertion_point(module_scope)
